@@ -20,10 +20,12 @@
  */
 typedef struct tzEntry
 {
-	/* the actual data: TZ abbrev (downcased), offset, DST flag */
-	char	   *abbrev;
-	int			offset;			/* in seconds from UTC */
-	bool		is_dst;
+	/* the actual data */
+	char	   *abbrev;			/* TZ abbreviation (downcased) */
+	char	   *zone;			/* zone name if dynamic abbrev, else NULL */
+	/* for a dynamic abbreviation, offset/is_dst are not used */
+	int			offset;			/* offset in seconds from UTC */
+	bool		is_dst;			/* true if a DST abbreviation */
 	/* source information (for error messages) */
 	int			lineno;
 	const char *filename;
